summaryrefslogtreecommitdiff
path: root/conftest.py
diff options
context:
space:
mode:
authorEevee (Alex Munroe) <eevee.git@veekun.com>2013-08-16 13:08:59 -0700
committerEevee (Alex Munroe) <eevee.git@veekun.com>2013-08-16 13:09:44 -0700
commitd8ed955318f28cd9aa96bc7e18ce51014e9a1a71 (patch)
treec3a69a68a5de0db994c80ee419a1dee7b9a8c946 /conftest.py
parentd2cdd641857af07a5439e8b8fb2e2b5110aa9566 (diff)
downloadpyscss-d8ed955318f28cd9aa96bc7e18ce51014e9a1a71.tar.gz
Make py.test have reasonable default behavior.
- Tests ported from Ruby and sassc are skipped by default. - New xfail directory for test files known to be broken.
Diffstat (limited to 'conftest.py')
-rw-r--r--conftest.py8
1 files changed, 7 insertions, 1 deletions
diff --git a/conftest.py b/conftest.py
index 01b04d1..445657d 100644
--- a/conftest.py
+++ b/conftest.py
@@ -1,12 +1,18 @@
"""py.test plugin configuration."""
def pytest_addoption(parser):
"""Add an option for filtering the file tests run.
This has to be done in the project root; py.test doesn't (and can't)
recursively look for conftest.py files until after it's parsed the command
line.
"""
+ parser.addoption('--include-ruby',
+ help='run tests imported from Ruby and sassc, most of which fail',
+ action='store_true',
+ dest='include_ruby',
+ )
+
parser.addoption('--test-file-filter',
help='comma-separated regexes to select test files',
action='store',
@@ -1,12 +1,18 @@
"""py.test plugin configuration."""
def pytest_addoption(parser):
- """Add an option for filtering the file tests run.
+ """Add options for filtering which file tests run.
This has to be done in the project root; py.test doesn't (and can't)
recursively look for conftest.py files until after it's parsed the command